@@ -443,7 +443,7 @@ class Model:
                 for table in data['table']:
                     if variable.name in table:
                         n=n+1
-                        self.__variables.append(Variable(variable.name,variable.row+n,variable.column,table[variable.name]))
+                        self.__variables.append(Variable(variable.name+str(n),variable.row+n,variable.column,table[variable.name]))
         return None
 
     def past_in_worksheet(self,worksheet):
